<?php

namespace Drupal\mnc\EventSubscriber;

use Drupal\Core\Ajax\SettingsCommand;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\mnc\Services\MessagesHelper;
use Drupal\views\Ajax\ViewAjaxResponse;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\Event\ResponseEvent;
use Symfony\Component\HttpKernel\KernelEvents;

/**
 * Provides a response subscriber to add the new message count.
 */
class AjaxResponseSubscriber implements EventSubscriberInterface {

  /**
   * The mnc.settings configuration object.
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * The messages helper.
   *
   * @var \Drupal\mnc\Services\MessagesHelper
   */
  protected $messagesHelper;

  /**
   * Constructs a new \Drupal\mnc\EventSubscriber\AjaxResponseEvent object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration object factory.
   * @param \Drupal\mnc\Services\MessagesHelper $messages_helper
   *   The messages helper.
   */
  public function __construct(ConfigFactoryInterface $config_factory, MessagesHelper $messages_helper) {
    $this->config = $config_factory->get('mnc.settings');
    $this->messagesHelper = $messages_helper;
  }

  /**
   * Renders the ajax commands right before preparing the result.
   *
   * @param \Symfony\Component\HttpKernel\Event\ResponseEvent $event
   *   The response event, which contains the possible AjaxResponse object.
   */
  public function onResponse(ResponseEvent $event): void {
    $response = $event->getResponse();

    // Only alter views ajax responses.
    if (!$response instanceof ViewAjaxResponse) {
      return;
    }

    // Only alter commands if the view is ours.
    $view = $response->getView();
    if ($view->storage->id() !== $this->config->get('view')){
      return;
    }

    $setting['mnc']['unread_count'] = $this->messagesHelper->getUnreadMessagesCount();
    $response->addCommand(new SettingsCommand($setting, TRUE));

    $event->setResponse($response);
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [KernelEvents::RESPONSE => [['onResponse']]];
  }

}
