<?php

namespace Drupal\mnc\Services;

use Drupal\Core\DependencyInjection\ClassResolverInterface;

/**
 * Provides a method to resolve a callback from different notations.
 *
 * TODO: Do we really need this or can we just limit ourselves to (tagged)
 *   services?
 */
class CallbackResolver {

  /**
   * The class resolver.
   * @var \Drupal\Core\DependencyInjection\ClassResolverInterface
   */
  protected $classResolver;

  /**
   * Constructs a \Drupal\mnc\Services\CallbackResolver object.
   *
   * @param \Drupal\Core\DependencyInjection\ClassResolverInterface $class_resolver
   *   The class resolver.
   */
  public function __construct(ClassResolverInterface $class_resolver) {
    $this->classResolver = $class_resolver;
  }

  /**
   * Resolves a callable from different notations.
   *
   * @param mixed $callback
   *
   * @return callable|null
   *   The resolved callable or null if the callable could not be resolved.
   */
  public function resolve($callback): ?callable {
    // If the callback is already a callable we can just return it.
    if (is_callable($callback)) {
      return $callback;
    }

    // If we have a string with a semicolon we assume a service notation.
    if (is_string($callback) && strpos($callback, ':') > 0) {
      [$service_id, $method] = explode(':', $callback, 2);
      $service = $this->classResolver->getInstanceFromDefinition($service_id);
      $callable = [$service, $method];
      if (is_callable($callable)) {
        return $callable;
      }
    }

    return NULL;
  }

}
